SQUAD - Software Quality Dashboard
==================================

SQUAD is a Software Quality Dashboard written in Python 3. It uses
Django.

See `the documentation folder`_ for more documentation, or go `browse the
documentation online`_

.. _`the documentation folder`: doc/
.. _`browse the documentation online`: https://squad.readthedocs.io/

License
-------

Copyright © 2016-2017 Linaro Limited

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

.. vim: tw=72
